@@ -12,7 +12,8 @@ class TokenizeUseGraffl(object):
     __acronym_delimiter = '~~'
 
     def __init__(self):
-        """
+        """ Change Log
+
         Created:
             29-Sept-2021
             craigtrim@gmail.com
@@ -149,16 +150,41 @@ class TokenizeUseGraffl(object):
             master = []
             buffer = []
 
-            prior_ch = None
-            for ch in token:
+            token_len = len(token)
+
+            for i in range(token_len):
+
+                def get_p1() -> str or None:
+                    if i - 1 >= 0:
+                        return token[i - 1]
+
+                def get_p2() -> str or None:
+                    if i - 2 >= 0:
+                        return token[i - 2]
+
+                def get_n1() -> str or None:
+                    if i + 1 < token_len:
+                        return token[i + 1]
+
+                def get_n2() -> str or None:
+                    if i + 2 < token_len:
+                        return token[i + 2]
+
+                p2 = get_p2()
+                p1 = get_p1()
+                ch = token[i]
+                n1 = get_n1()
+                n2 = get_n2()
 
                 # fast-sentence-tokenize#1; keep underscored entities together
                 if ch.isalpha() or ch.isnumeric() or ch in [' ', '_']:
                     buffer.append(ch)
-                elif ch in ['.', ','] and prior_ch and prior_ch.isnumeric():
+                elif ch in ['.', ','] and p1 and p1.isnumeric():
                     buffer.append(ch)  # e.g., 1.06 or 325,000
-                elif ch == "'" and prior_ch and prior_ch.isalpha():
+                elif ch == "'" and p1 and p1.isalpha():
                     buffer.append(ch)  # e.g., Women's
+                elif ch == "&" and p1 and p1.isalpha() and n1 and n1.isalpha():
+                    buffer.append(ch)  # e.g., A&W
                 else:
                     if len(buffer):
                         master.append(''.join(buffer))
@@ -166,7 +192,7 @@ class TokenizeUseGraffl(object):
                         master.append(ch)
                     buffer = []
 
-                prior_ch = ch
+                i += 1
 
             if len(buffer):
                 master.append(''.join(buffer))
